==========================
 ``zope.event`` Changelog
==========================

4.3.0 (2017-07-25)
==================

- Add support for Python 3.6.

- Drop support for Python 3.3.


4.2.0 (2016-02-17)
==================

- Add support for Python 3.5.

- Drop support for Python 2.6 and 3.2.


4.1.0 (2015-10-18)
==================

- Require 100% branch (as well as statement) coverage.

- Add a simple class-based handler implementation.


4.0.3 (2014-03-19)
==================

- Add support for Python 3.4.

- Update ``boostrap.py`` to version 2.2.


4.0.2 (2012-12-31)
==================

- Flesh out PyPI Trove classifiers.

- Add support for jython 2.7.


4.0.1 (2012-11-21)
==================

- Add support for Python 3.3.


4.0.0 (2012-05-16)
==================

- Automate build of Sphinx HTML docs and running doctest snippets via tox.

- Drop explicit support for Python 2.4 / 2.5 / 3.1.

- Add support for PyPy.


3.5.2 (2012-03-30)
==================

- This release is the last which will maintain support for Python 2.4 /
  Python 2.5.

- Add support for continuous integration using ``tox`` and ``jenkins``.

- Add 'setup.py dev' alias (runs ``setup.py develop`` plus installs
  ``nose`` and ``coverage``).

- Add 'setup.py docs' alias (installs ``Sphinx`` and dependencies).


3.5.1 (2011-08-04)
==================

- Add Sphinx documentation.


3.5.0 (2010-05-01)
==================

- Add change log to ``long-description``.

- Add support for Python 3.x.


3.4.1 (2009-03-03)
==================

- A few minor cleanups.


3.4.0 (2007-07-14)
==================

- Initial release as a separate project.
